/*
 * This File is part of the iowj-project   
 * $Id: IowInterface.java,v 1.8 2005/11/19 15:44:21 Thomas Wagner Exp $
 * Copyright (C)2004 by Thomas Wagner
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
package de.wagner_ibw.iow;

/**
 * This Interface contains basic methods for each Iow device.
 * @author Thomas Wagner
 */
public interface IowInterface {
	
	/**
	 * @since 0.9.3 with long return value
	 */
	long readIOPorts();

	/**
	 * 
	 * @param pipe
	 * @return Array of int.
	 */
	int[] readReport(int pipe);
	
	/**
	 * 
	 * @param pipe
	 * @param wbuf
	 * @return Array of int.
	 */
	long writeReport(int pipe, int[] wbuf);
	
	/**
	 * 
	 * @return Handle as long
	 */
	long getHandle();
	
	/**
	 * 
	 * @return Serialnomber as string.
	 */
	String getSerial();
	
	/**
	 * 
	 * @return Id as int.
	 */
	int getId();
	
	/**
	 * 
	 * @return Revision as int.
	 * @since 0.9.3
	 */
	int getRev();
	
	/**
	 * 
	 * @return Name as string.
	 */
	String getName();
	
	/**
	 * Set the direction mask to the given port.
	 * @param port Port number (0...3).
	 * @param direction 0-output, 1-input
	 * @since 0.9.4
	 */
	void setDirection(int port, int direction) throws IllegalArgumentException;
	
	/**
	 * Set the given bit froma the given port.
	 * @param port Port number (0...1).
	 * @param bit Bit number (0...7).
	 * @since 0.9.4
	 */
	void setBit(int port, int bit) throws IllegalArgumentException;

	/**
	 * Clear the given bit froma the given port.
	 * @param port Port number (0...1).
	 * @param bit Bit number (0...7).
	 * @since 0.9.4
	 */
	void clearBit(int port, int bit)	throws IllegalArgumentException;
	
	/**
	 * Write the preseted ports.
	 * @since 0.9.4
	 */
	void writeIOPorts();
	
}
